Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(240)

Unified Diff: components/html_viewer/ax_provider_apptest.cc

Issue 1294473008: Makes OOPIFs the default (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: cleanup Created 5 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: components/html_viewer/ax_provider_apptest.cc
diff --git a/components/html_viewer/ax_provider_apptest.cc b/components/html_viewer/ax_provider_apptest.cc
index 073926c30c0319d21a98f089885f464ccd33d980..11b4cf21c405061436620b697b79cc1af50561f5 100644
--- a/components/html_viewer/ax_provider_apptest.cc
+++ b/components/html_viewer/ax_provider_apptest.cc
@@ -30,11 +30,13 @@ bool AxTreeContainsText(const Array<AxNodePtr>& tree, const String& text) {
return false;
}
-// Switch to enable out of process iframes.
-const char kOOPIF[] = "oopifs";
+// Switch to disable out of process iframes.
+const char kDisableOOPIF[] = "disable--oopifs";
bool EnableOOPIFs() {
- return base::CommandLine::ForCurrentProcess()->HasSwitch(kOOPIF);
+ if (base::CommandLine::ForCurrentProcess()->HasSwitch(kDisableOOPIF))
+ return false;
+ return true;
}
class TestFrameTreeServer : public mandoline::FrameTreeServer {

Powered by Google App Engine
This is Rietveld 408576698